==> qtjambi-datavisualization-6.6.1-sources.jar: io/qt/datavis/QSurfaceDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QSurfaceDataArray</a></code></p>
 */
public class QSurfaceDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QSurfaceDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QSurfaceDataArray::<wbr/>QSurfaceDataArray()</code></p>
     */
    public QSurfaceDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSurfaceDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSurfaceDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QSurfaceDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QSurfaceDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QSurfaceDataArray clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.7.1-sources.jar: io/qt/datavis/QSurfaceDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QSurfaceDataArray</a></code></p>
 */
public class QSurfaceDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QSurfaceDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QSurfaceDataArray::<wbr/>QSurfaceDataArray()</code></p>
     */
    public QSurfaceDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSurfaceDataArray instance);
    
    /**
     * <p>See <code>QSurfaceDataArray::<wbr/>QSurfaceDataArray(QSurfaceDataArray)</code></p>
     */
    public QSurfaceDataArray(io.qt.datavis.@NonNull QSurfaceDataArray other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QSurfaceDataArray instance, io.qt.datavis.QSurfaceDataArray other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSurfaceDataArray(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QSurfaceDataArray::<wbr/>QSurfaceDataArray(QSurfaceDataArray)</code></p>
     */
    @QtUninvokable
    @Override
    public QSurfaceDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QSurfaceDataArray clone_native(long __this_nativeId);
}
